<img src="https://raw.githubusercontent.com/oskvr37/enviz/main/logo.svg" width="100%"/>

# About

Enviz is a python module that allows you to write and read environment variables from a file.

# Installation

```bash
pip install enviz
```
